@@ -45,6 +45,12 @@
 #include "definitions.hpp"
 #include "Urids.hpp"
 
+#ifdef LOCALEFILE
+#include LOCALEFILE
+#else
+#include "Locale_EN.hpp"
+#endif
+
 #ifndef MESSAGENR_
 #define MESSAGENR_
 enum MessageNr
@@ -67,7 +73,7 @@ enum MessageNr
 #define BG_FILE "surface.png"
 #define HELP_URL "https://github.com/sjaehn/BChoppr/blob/master/README.md"
 #define YT_URL " https://youtu.be/PuzoxiAs-h8"
-#define OPEN_CMD "xdg-open"
+#define WWW_BROWSER_CMD "x-www-browser"
 
 #define DB_CO(g) ((g) > -90.0f ? powf(10.0f, (g) * 0.05f) : 0.0f)
 #define CO_DB(g) ((g) > 0.0001f ? logf((g)) / 0.05f : -90.0f)
@@ -78,13 +84,13 @@ enum MessageNr
 const std::string messageStrings[MAX_MSG + 1] =
 {
 	"",
-	"*** Jack transport off or halted. ***"
+	"*** " BCHOPPR_LABEL_JACK_STOP " ***"
 };
 
 class BChoppr_GUI : public BWidgets::Window
 {
 public:
-	BChoppr_GUI (const char *bundle_path, const LV2_Feature *const *features, PuglNativeWindow parentWindow);
+	BChoppr_GUI (const char *bundle_path, const LV2_Feature *const *features, PuglNativeView parentWindow);
 	~BChoppr_GUI ();
 	void portEvent (uint32_t port_index, uint32_t buffer_size, uint32_t format, const void *buffer);
 	void send_record_on ();
@@ -219,6 +225,8 @@ private:
 	BStyles::Border screenBorder = BStyles::Border (BStyles::Line (BColors::Color (0.0, 0.0, 0.0, 0.75), 4.0));
 	BStyles::Font defaultFont = BStyles::Font ("Sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL, 12.0,
 						   BStyles::TEXT_ALIGN_CENTER, BStyles::TEXT_VALIGN_MIDDLE);
+   	BStyles::Font leftFont = BStyles::Font ("Sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL, 12.0,
+   						   BStyles::TEXT_ALIGN_LEFT, BStyles::TEXT_VALIGN_MIDDLE);
         BStyles::Font mdFont = BStyles::Font ("Sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL, 10.0,
                                          BStyles::TEXT_ALIGN_CENTER, BStyles::TEXT_VALIGN_MIDDLE);
         BStyles::Font smFont = BStyles::Font ("Sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL, 8.0,
@@ -230,6 +238,10 @@ private:
 						    {"border", STYLEPTR (&BStyles::noBorder)},
 						    {"textcolors", STYLEPTR (&txColors)},
 						    {"font", STYLEPTR (&defaultFont)}}};
+        BStyles::StyleSet llStyles = {"labels", {{"background", STYLEPTR (&BStyles::noFill)},
+                                                 {"border", STYLEPTR (&BStyles::noBorder)},
+                                                 {"textcolors", STYLEPTR (&txColors)},
+                                                 {"font", STYLEPTR (&leftFont)}}};
         BStyles::StyleSet mlStyles = {"labels", {{"background", STYLEPTR (&BStyles::noFill)},
                                                  {"border", STYLEPTR (&BStyles::noBorder)},
                                                  {"textcolors", STYLEPTR (&fgColors)},
@@ -303,6 +315,7 @@ private:
 				 {"textcolors", STYLEPTR (&txColors)},
 				 {"font", STYLEPTR (&defaultFont)}}},
 		{"label",	{{"uses", STYLEPTR (&labelStyles)}}},
+                {"llabel",	{{"uses", STYLEPTR (&llStyles)}}},
                 {"mlabel",	{{"uses", STYLEPTR (&mlStyles)}}},
                 {"smlabel",	{{"uses", STYLEPTR (&smStyles)}}},
 		{"hilabel",	{{"uses", STYLEPTR (&labelStyles)},
